@@ -1,7 +1,7 @@
-#' h2 vector for 15 diseases
+#' h2 vector for 62 traits
 #'
 #' Example h2 vector used in the vignette and examples.
 #'
 #' @format A numeric matrix.
 #' @source Internal simulation
-"h2_vector_15D"
+"h2_vector"
