@@ -1,7 +1,7 @@
-#' h2 jk matrix for 15 diseases
+#' h2 jk matrix for 62 traits
 #'
 #' Example h2 jk matrix used in the vignette and examples.
 #'
 #' @format A numeric matrix.
 #' @source Internal simulation
-"h2_vector_mat_15D"
+"h2_vector_mat"
