@@ -1,7 +1,7 @@
-#' Genetic correlation matrix for 15 diseases
+#' Genetic correlation matrix for 62 traits
 #'
 #' Example genetic correlation matrix used in the vignette and examples.
 #'
 #' @format A numeric matrix.
 #' @source Internal simulation
-"Results_full_rg_15D"
+"Results_full_rg"
